function [mat1, mat2, mat3, mat4] = cooc(Image,color,D)
%--------------------------------------------------------------------------
%function [mat1, mat2, mat3, mat4] = cooc(Image,color,D)
%
% Calculation of the normalized co-occurance matrix of one color of an rgb picture
% input:    Image:  RGB Image   
%           color:  1=red, 2=green, 3=blue
%           D:      distance in pixel of the pair of pixels considered
%
% output:   mat1,...,mat4: the co-occurances 
%                          matrices corresponding to the
%                          angles 135, 90, 45, 0 respectively 
%--------------------------------------------------------------------------
% Date:   31.10.2004
% Author: Maja Temerinac

[m,n] = size(Image(:,:,color));

%mx = max(max(Image(:,:,color)));
%mx = double(mx);
mx = 256;

mat1 = zeros(mx,mx);
mat2 = zeros(mx,mx);
mat3 = zeros(mx,mx);
mat4 = zeros(mx,mx);

%135 degrees
count1 = 0;
for r=1+D:m,
	for c=1+D:n,
		row = double(Image(r,c,color)) + 1;
		col = double(Image(r-D,c-D,color)) + 1;
            if(row==col)
		        count1 = count1 + 1;
                mat1(row,col) = mat1(row,col) + 1;
                 else
                    count1 = count1 + 2;  
                    mat1(row,col) = mat1(row,col) + 1;
                    mat1(col,row) = mat1(col,row) + 1;    
            end
	end
end
mat1 = mat1./count1;

%90 degrees
count2 = 0;
for r=1+D:m,
	for c=1:n,
		row = double(Image(r,c,color)) + 1;
		col = double(Image(r-D,c,color)) + 1;
		if(row==col)
		    count2 = count2 + 1;    
            mat2(row,col) = mat2(row,col) + 1;
                 else
                    count2 = count2 +2;
                     mat2(row,col) = mat2(row,col) + 1;
                    mat2(col,row) = mat2(col,row) + 1;    
            end     
	end
end
mat2 = mat2./count2;

%45 degrees
count3 = 0;
for r=1+D:m,
	for c=1:n-D,
		row = double(Image(r,c,color)) + 1;
		col = double(Image(r-D,c+D,color)) + 1;
		if(row==col)
		    count3 = count3 + 1;    
            mat3(row,col) = mat3(row,col) + 1;
                 else
                    count3 = count3 + 2;
                    mat3(row,col) = mat3(row,col) + 1;
                    mat3(col,row) = mat3(col,row) + 1;    
            end
	end
end
mat3 = mat3./count3;
%0 degrees
count4 = 0;
for r=1:m,
	for c=1:n-D,
		row = double(Image(r,c,color)) + 1;
		col = double(Image(r,c+D,color)) + 1;
		if(row==col)
		    count4 = count4 + 1;    
            mat4(row,col) = mat4(row,col) + 1;
                 else
                    count4 = count4 + 2;
                    mat4(row,col) = mat4(row,col) + 1;
                    mat4(col,row) = mat4(col,row) + 1;    
            end
	end
end
mat4 = mat4./count4;
