function fvec = create14_gray_fts(image,D)
%-------------------------------------------------------------------------
% function fvec = create14_gray_fts(image,D)
% 
% Calculation of the feature vector
%
% input:    image              (n x m x 3) matrix containing information about a rgb
%                               picture      
%           D                   distance in pixel for the calculation of the co-occurence matrix    
%
% output:   fvec                feature vector
%-------------------------------------------------------------------------
% Date: 26.12.2004
% Name: Maja Temerinac

%feature vector containing
%asm(mean,range),contrast(mean,range),entropy(mean,range),
%idm(mean,contrast),correlation(mean,range),im1(mean,range),im2(mean,range)

n = 14;
fvec = zeros(n,1);

%creating hsv image from rgb and scaling to values in the range 0,..,255
%integer
image = rgb2gray(image);

%compute co-occurance matrix
%yuv
[rmat1,rmat2,rmat3,rmat4] = cooc(image,1,D);

%compute mean value
%y
rmat_mean = (rmat1+rmat2+rmat3+rmat4)/4;

%compute range value
%y
rmat_range = max(rmat1,max(rmat2,max(rmat3,rmat4)))-min(rmat1,min(rmat2,min(rmat3,rmat4)));

%mean value of asm
%y
m_rasm = asm(rmat_mean);

fvec(1) = m_rasm; 

%range value of asm
%y
r_rasm = asm(rmat_range);

fvec(2) = r_rasm; 

%mean value of contrast
%y
m_rcontrast = contrast(rmat_mean);

fvec(3) = m_rcontrast; 

%range value of contrast
%y
r_rcontrast = contrast(rmat_range);

fvec(4) = r_rcontrast;

%mean value of entropy
%y
m_rentropy = entropy(rmat_mean);

fvec(5) = m_rentropy;

%range value of entropy
%y
r_rentropy = entropy(rmat_range);

fvec(6) = r_rentropy;

%mean value of inverse difference moment
%y
m_ridm = idm(rmat_mean);

fvec(7) = m_ridm;

%range value of inverse difference moment
%y
r_ridm = idm(rmat_range);

fvec(8) = r_ridm;

%mean value of correlation
%y
m_rcorrelation = correlation(rmat_mean);

fvec(9) = m_rcorrelation;

%range value of correlation
%y
r_rcorrelation = correlation(rmat_range);

fvec(10) = r_rcorrelation;

%mean value of im1
%y
m_rim1 = im1(rmat_mean);

fvec(11) = m_rim1;

%range value of im1
%y
r_rim1 = im1(rmat_range);

fvec(12) = r_rim1;

%mean value of im2
%y
m_rim2 = im2(rmat_mean);

fvec(13) = m_rim2;

%range value of im2
%y
r_rim2 = im2(rmat_range);

fvec(14) = r_rim2;

