function fvec = create14_sumRGB_fts(image,D)
%-------------------------------------------------------------------------
% function fvec = create14_sumRGB_fts(image,D)
% 
% Calculation of the feature vector
%
% input:    image              (n x m x 3) matrix containing information about a rgb
%                               picture      
%           D                   distance in pixel for the calculation of the co-occurence matrix    
%
% output:   fvec                feature vector for sum(rgb)
%-------------------------------------------------------------------------
% Date: 2.11.2004
% Name: Maja Temerinac

%feature vector containing
%asm(mean,range),contrast(mean,range),entropy(mean,range),
%idm(mean,contrast),correlation(mean,range),im1(mean,range),im2(mean,range)


n = 14;
fvec = zeros(n,1);

%compute co-occurance matrix
%red
[rmat1,rmat2,rmat3,rmat4] = cooc(image,1,D);
%green
[gmat1,gmat2,gmat3,gmat4] = cooc(image,2,D);
%blue
[bmat1,bmat2,bmat3,bmat4] = cooc(image,3,D);

%compute mean rgb co-occurance matrix
mat1 = rmat1+gmat1+bmat1;
mat2 = rmat2+gmat2+bmat2;
mat3 = rmat3+gmat3+bmat3;
mat4 = rmat4+gmat4+bmat4;


%compute mean value of the four directions
mat_mean = (mat1+mat2+mat3+mat4)/4;

%compute range value of the four directions
mat_range = max(mat1,max(mat2,max(mat3,mat4)))-min(mat1,min(mat2,min(mat3,mat4)));

%mean value of asm
m_asm = asm(mat_mean);

fvec(1) = m_asm; 

%range value of asm
r_asm = asm(mat_range);

fvec(2) = r_asm; 

%mean value of contrast
m_contrast = contrast(mat_mean);

fvec(3) = m_contrast; 

%range value of contrast
r_contrast = contrast(mat_range);

fvec(4) = r_contrast;

%mean value of entropy
m_entropy = entropy(mat_mean);

fvec(5) = m_entropy;

%range value of entropy
r_entropy = entropy(mat_range);

fvec(6) = r_entropy;

%mean value of inverse difference moment
m_idm = idm(mat_mean);

fvec(7) = m_idm;

%range value of inverse difference moment
r_idm = idm(mat_range);

fvec(8) = r_idm;

%mean value of correlation
m_correlation = correlation(mat_mean);

fvec(9) = m_correlation;

%range value of correlation
r_correlation = correlation(mat_range);

fvec(10) = r_correlation;

%mean value of im1
m_im1 = im1(mat_mean);

fvec(11) = m_im1;

%range value of im1
r_im1 = im1(mat_range);

fvec(12) = r_im1;

%mean value of im2
m_im2 = im2(mat_mean);

fvec(13) = m_im2;

%range value of im2
r_im2 = im2(mat_range);

fvec(14) = r_im2;

