function fvec = create28_HSV_fts(image,D)
%-------------------------------------------------------------------------
% function fvec = create28_HSV_fts(image,D)
% 
% Calculation of the feature vector
%
% input:    image              (n x m x 3) matrix containing information about a rgb
%                               picture      
%           D                   distance in pixel for the calculation of the co-occurence matrix    
%
% output:   fvec                feature vector
%-------------------------------------------------------------------------
% Date: 2.11.2004
% Name: Maja Temerinac

%feature vector containing
%asm(mean,range),contrast(mean,range),entropy(mean,range),
%idm(mean,contrast),correlation(mean,range),im1(mean,range),im2(mean,range)
%,variance(mean,range), sumav(mean,range),sumvar(mean,range),sumentropy(mean,range),
%diffvar(mean,range), diffentropy(mean,range),mcc(mean,range),n=28

n = 28;
fvec = zeros(n,3);

%creating hsv image from rgb and scaling to values in the range 0,..,255
%integer
image = uint8(255*rgb2hsv(image));

%compute co-occurance matrix
%red
[rmat1,rmat2,rmat3,rmat4] = cooc(image,1,D);
%green
[gmat1,gmat2,gmat3,gmat4] = cooc(image,2,D);
%blue
[bmat1,bmat2,bmat3,bmat4] = cooc(image,3,D);

%compute mean value
%red
rmat_mean = (rmat1+rmat2+rmat3+rmat4)/4;
%green
gmat_mean = (gmat1+gmat2+gmat3+gmat4)/4;
%blue
bmat_mean = (bmat1+bmat2+bmat3+bmat4)/4;

%compute range value
%red
rmat_range = max(rmat1,max(rmat2,max(rmat3,rmat4)))-min(rmat1,min(rmat2,min(rmat3,rmat4)));
%green
gmat_range = max(gmat1,max(gmat2,max(gmat3,gmat4)))-min(gmat1,min(gmat2,min(gmat3,gmat4)));
%blue
bmat_range = max(bmat1,max(bmat2,max(bmat3,bmat4)))-min(bmat1,min(bmat2,min(bmat3,bmat4)));

%mean value of asm
%red
m_rasm = asm(rmat_mean);
%green
m_gasm = asm(gmat_mean);
%blue
m_basm = asm(bmat_mean);

fvec(1,:) = [m_rasm,m_gasm,m_basm]; 

%range value of asm
%red
r_rasm = asm(rmat_range);
%green
r_gasm = asm(gmat_range);
%blue
r_basm = asm(bmat_range);

fvec(2,:) = [r_rasm,r_gasm,r_basm]; 

%mean value of contrast
%red
m_rcontrast = contrast(rmat_mean);
%green
m_gcontrast = contrast(gmat_mean);
%blue
m_bcontrast = contrast(bmat_mean);

fvec(3,:) = [m_rcontrast,m_gcontrast,m_bcontrast]; 

%range value of contrast
%red
r_rcontrast = contrast(rmat_range);
%green
r_gcontrast = contrast(gmat_range);
%blue
r_bcontrast = contrast(bmat_range);

fvec(4,:) = [r_rcontrast,r_gcontrast,r_bcontrast];

%mean value of entropy
%red
m_rentropy = entropy(rmat_mean);
%green
m_gentropy = entropy(gmat_mean);
%blue
m_bentropy = entropy(bmat_mean);

fvec(5,:) = [m_rentropy,m_gentropy,m_bentropy];

%range value of entropy
%red
r_rentropy = entropy(rmat_range);
%green
r_gentropy = entropy(gmat_range);
%blue
r_bentropy = entropy(bmat_range);

fvec(6,:) = [r_rentropy,r_gentropy,r_bentropy];

%mean value of inverse difference moment
%red
m_ridm = idm(rmat_mean);
%green
m_gidm = idm(gmat_mean);
%blue
m_bidm = idm(bmat_mean);

fvec(7,:) = [m_ridm,m_gidm,m_bidm];

%range value of inverse difference moment
%red
r_ridm = idm(rmat_range);
%green
r_gidm = idm(gmat_range);
%blue
r_bidm = idm(bmat_range);

fvec(8,:) = [r_ridm,r_gidm,r_bidm];

%mean value of correlation
%red
m_rcorrelation = correlation(rmat_mean);
%green
m_gcorrelation = correlation(gmat_mean);
%blue
m_bcorrelation = correlation(bmat_mean);

fvec(9,:) = [m_rcorrelation,m_gcorrelation,m_bcorrelation];

%range value of correlation
%red
r_rcorrelation = correlation(rmat_range);
%green
r_gcorrelation = correlation(gmat_range);
%blue
r_bcorrelation = correlation(bmat_range);

fvec(10,:) = [r_rcorrelation,r_gcorrelation,r_bcorrelation];

%mean value of im1
%red
m_rim1 = im1(rmat_mean);
%green
m_gim1 = im1(gmat_mean);
%blue
m_bim1 = im1(bmat_mean);

fvec(11,:) = [m_rim1,m_gim1,m_bim1];

%range value of im1
%red
r_rim1 = im1(rmat_range);
%green
r_gim1 = im1(gmat_range);
%blue
r_bim1= im1(bmat_range);

fvec(12,:) = [r_rim1,r_gim1,r_bim1];

%mean value of im2
%red
m_rim2 = im2(rmat_mean);
%green
m_gim2 = im2(gmat_mean);
%blue
m_bim2 = im2(bmat_mean);

fvec(13,:) = [m_rim2,m_gim2,m_bim2];

%range value of im2
%red
r_rim2 = im2(rmat_range);
%green
r_gim2 = im2(gmat_range);
%blue
r_bim2= im2(bmat_range);

fvec(14,:) = [r_rim2,r_gim2,r_bim2];

%mean value of variance
%red
m_rvariance = variance(rmat_mean);
%green
m_gvariance = variance(gmat_mean);
%blue
m_bvariance = variance(bmat_mean);

fvec(15,:) = [m_rvariance,m_gvariance,m_bvariance];

%range value of variance
%red
r_rvariance = variance(rmat_range);
%green
r_gvariance = variance(gmat_range);
%blue
r_bvariance= variance(bmat_range);

fvec(16,:) = [r_rvariance,r_gvariance,r_bvariance];

%mean value of sum average
%red
m_rsumav = sumav(rmat_mean);
%green
m_gsumav = sumav(gmat_mean);
%blue
m_bsumav = sumav(bmat_mean);

fvec(17,:) = [m_rsumav,m_gsumav,m_bsumav];

%range value of sum average
%red
r_rsumav = sumav(rmat_range);
%green
r_gsumav = sumav(gmat_range);
%blue
r_bsumav = sumav(bmat_range);

fvec(18,:) = [r_rsumav,r_gsumav,r_bsumav];

%mean value of sum variance
%red
m_rsumvar = sumvar(rmat_mean);
%green
m_gsumvar = sumvar(gmat_mean);
%blue
m_bsumvar = sumvar(bmat_mean);

fvec(19,:) = [m_rsumvar,m_gsumvar,m_bsumvar];

%range value of sum variance
%red
r_rsumvar = sumvar(rmat_range);
%green
r_gsumvar = sumvar(gmat_range);
%blue
r_bsumvar = sumvar(bmat_range);

fvec(20,:) = [r_rsumvar,r_gsumvar,r_bsumvar];

%mean value of sum entropy
%red
m_rsumentropy = sumentropy(rmat_mean);
%green
m_gsumentropy = sumentropy(gmat_mean);
%blue
m_bsumentropy = sumentropy(bmat_mean);

fvec(21,:) = [m_rsumentropy,m_gsumentropy,m_bsumentropy];

%range value of entropy
%red
r_rsumentropy = sumentropy(rmat_range);
%green
r_gsumentropy = sumentropy(gmat_range);
%blue
r_bsumentropy = sumentropy(bmat_range);

fvec(22,:) = [r_rsumentropy,r_gsumentropy,r_bsumentropy];

%mean value of difference variance
%red
m_rdiffvar = diffvar(rmat_mean);
%green
m_gdiffvar = diffvar(gmat_mean);
%blue
m_bdiffvar = diffvar(bmat_mean);

fvec(23,:) = [m_rdiffvar,m_gdiffvar,m_bdiffvar];

%range value of difference variance
%red
r_rdiffvar = diffvar(rmat_range);
%green
r_gdiffvar = diffvar(gmat_range);
%blue
r_bdiffvar = diffvar(bmat_range);

fvec(24,:) = [r_rdiffvar,r_gdiffvar,r_bdiffvar];

%mean value of difference entropy
%red
m_rdiffentropy = diffentropy(rmat_mean);
%green
m_gdiffentropy = diffentropy(gmat_mean);
%blue
m_bdiffentropy = diffentropy(bmat_mean);

fvec(25,:) = [m_rdiffentropy,m_gdiffentropy,m_bdiffentropy];

%range value of difference entropy
%red
r_rdiffentropy = diffentropy(rmat_range);
%green
r_gdiffentropy = diffentropy(gmat_range);
%blue
r_bdiffentropy = diffentropy(bmat_range);

fvec(26,:) = [r_rdiffentropy,r_gdiffentropy,r_bdiffentropy];

%mean value of maximal correalation coefficient
%red
m_rmcc = mcc(rmat_mean);
%green
m_gmcc = mcc(gmat_mean);
%blue
m_bmcc = mcc(bmat_mean);

fvec(27,:) = [m_rmcc,m_gmcc,m_bmcc];

%range value of maximal correlation coefficient
%red
r_rmcc = mcc(rmat_range);
%green
r_gmcc = mcc(gmat_range);
%blue
r_bmcc = mcc(bmat_range);

fvec(28,:) = [r_rmcc,r_gmcc,r_bmcc];
