function fvec = create28_sumRGB_fts(image,D)
%-------------------------------------------------------------------------
% function fvec = create28_sumRGB_fts(image,D)
% 
% Calculation of the feature vector
%
% input:    image              (n x m x 3) matrix containing information about a rgb
%                               picture      
%           D                   distance in pixel for the calculation of the co-occurence matrix    
%
% output:   fvec                feature vector for sum(rgb)
%-------------------------------------------------------------------------
% Date: 2.11.2004
% Name: Maja Temerinac

%feature vector containing
%asm(mean,range),contrast(mean,range),entropy(mean,range),
%idm(mean,contrast),correlation(mean,range),im1(mean,range),im2(mean,range)
%,variance(mean,range), sumav(mean,range),sumvar(mean,range),sumentropy(mean,range),
%diffvar(mean,range), diffentropy(mean,range),mcc(mean,range),n=28


n = 28;
fvec = zeros(n,1);

%compute co-occurance matrix
%red
[rmat1,rmat2,rmat3,rmat4] = cooc(image,1,D);
%green
[gmat1,gmat2,gmat3,gmat4] = cooc(image,2,D);
%blue
[bmat1,bmat2,bmat3,bmat4] = cooc(image,3,D);

%compute mean rgb co-occurance matrix
mat1 = rmat1+gmat1+bmat1;
mat2 = rmat2+gmat2+bmat2;
mat3 = rmat3+gmat3+bmat3;
mat4 = rmat4+gmat4+bmat4;


%compute mean value of the four directions
mat_mean = (mat1+mat2+mat3+mat4)/4;

%compute range value of the four directions
mat_range = max(mat1,max(mat2,max(mat3,mat4)))-min(mat1,min(mat2,min(mat3,mat4)));

%mean value of asm
m_asm = asm(mat_mean);

fvec(1) = m_asm; 

%range value of asm
r_asm = asm(mat_range);

fvec(2) = r_asm; 

%mean value of contrast
m_contrast = contrast(mat_mean);

fvec(3) = m_contrast; 

%range value of contrast
r_contrast = contrast(mat_range);

fvec(4) = r_contrast;

%mean value of entropy
m_entropy = entropy(mat_mean);

fvec(5) = m_entropy;

%range value of entropy
r_entropy = entropy(mat_range);

fvec(6) = r_entropy;

%mean value of inverse difference moment
m_idm = idm(mat_mean);

fvec(7) = m_idm;

%range value of inverse difference moment
r_idm = idm(mat_range);

fvec(8) = r_idm;

%mean value of correlation
m_correlation = correlation(mat_mean);

fvec(9) = m_correlation;

%range value of correlation
r_correlation = correlation(mat_range);

fvec(10) = r_correlation;

%mean value of im1
m_im1 = im1(mat_mean);

fvec(11) = m_im1;

%range value of im1
r_im1 = im1(mat_range);

fvec(12) = r_im1;

%mean value of im2
m_im2 = im2(mat_mean);

fvec(13) = m_im2;

%range value of im2
r_im2 = im2(mat_range);

fvec(14) = r_im2;

%mean value of variance
m_variance = variance(mat_mean);

fvec(15) = m_variance;

%range value of variance
r_variance = variance(mat_range);

fvec(16) = r_variance;

%mean value of sum average
m_sumav = sumav(mat_mean);

fvec(17) = m_sumav;

%range value of sum average
r_sumav = sumav(mat_range);

fvec(18) = r_sumav;

%mean value of sum variance
m_sumvar = sumvar(mat_mean);

fvec(19) = m_sumvar;

%range value of sum variance
r_sumvar = sumvar(mat_range);

fvec(20) = r_sumvar;

%mean value of sum entropy
m_sumentropy = sumentropy(mat_mean);

fvec(21) = m_sumentropy;

%range value of entropy
r_sumentropy = sumentropy(mat_range);

fvec(22) = r_sumentropy;

%mean value of difference variance
m_diffvar = diffvar(mat_mean);

fvec(23) = m_diffvar;

%range value of difference variance
r_diffvar = diffvar(mat_range);

fvec(24) = r_diffvar;

%mean value of difference entropy
m_diffentropy = diffentropy(mat_mean);

fvec(25) = m_diffentropy;

%range value of difference entropy
r_diffentropy = diffentropy(mat_range);

fvec(26) = r_diffentropy;

%mean value of maximal correalation coefficient
m_mcc = mcc(mat_mean);

fvec(27) = m_mcc;

%range value of maximal correlation coefficient
r_mcc = mcc(mat_range);

fvec(28) = r_mcc;