function fvec = create_RGB_contrast(image,D)
%-------------------------------------------------------------------------
% function fvec = create_RGB_contrast(image,D)
% 
% Calculation of the feature vector
%
% input:    image              (n x m x 3) matrix containing information about a rgb
%                               picture      
%           D                   distance in pixel for the calculation of the co-occurence matrix    
%
% output:   fvec                feature vector
%-------------------------------------------------------------------------
% Date: 2.11.2004
% Name: Maja Temerinac

%feature vector containing
%entropy(mean,range)
n = 2;
fvec = zeros(n,3);


%compute co-occurance matrix
%red
[rmat1,rmat2,rmat3,rmat4] = cooc(image,1,D);
%green
[gmat1,gmat2,gmat3,gmat4] = cooc(image,2,D);
%blue
[bmat1,bmat2,bmat3,bmat4] = cooc(image,3,D);

%compute mean value
%red
rmat_mean = (rmat1+rmat2+rmat3+rmat4)/4;
%green
gmat_mean = (gmat1+gmat2+gmat3+gmat4)/4;
%blue
bmat_mean = (bmat1+bmat2+bmat3+bmat4)/4;

%compute range value
%red
rmat_range = max(rmat1,max(rmat2,max(rmat3,rmat4)))-min(rmat1,min(rmat2,min(rmat3,rmat4)));
%green
gmat_range = max(gmat1,max(gmat2,max(gmat3,gmat4)))-min(gmat1,min(gmat2,min(gmat3,gmat4)));
%blue
bmat_range = max(bmat1,max(bmat2,max(bmat3,bmat4)))-min(bmat1,min(bmat2,min(bmat3,bmat4)));


%mean value of contrast
%red
m_rcontrast = contrast(rmat_mean);
%green
m_gcontrast = contrast(gmat_mean);
%blue
m_bcontrast = contrast(bmat_mean);

fvec(1,:) = [m_rcontrast,m_gcontrast,m_bcontrast];

%range value of contrast
%red
r_rcontrast = contrast(rmat_range);
%green
r_gcontrast = contrast(gmat_range);
%blue
r_bcontrast = contrast(bmat_range);

fvec(2,:) = [r_rcontrast,r_gcontrast,r_bcontrast];

