function fvec = create_RGB_correlation(image,D)
%-------------------------------------------------------------------------
% function fvec = create_RGB_correlation(image,D)
% 
% Calculation of the feature vector
%
% input:    image              (n x m x 3) matrix containing information about a rgb
%                               picture      
%           D                   distance in pixel for the calculation of the co-occurence matrix    
%
% output:   fvec                feature vector
%-------------------------------------------------------------------------
% Date: 2.11.2004
% Name: Maja Temerinac

%feature vector containing
%asm(mean,range),contrast(mean,range),entropy(mean,range),
%idm(mean,contrast),correlation(mean,range),im1(mean,range),im2(mean,range)


n = 2;
fvec = zeros(n,3);


%compute co-occurance matrix
%red
[rmat1,rmat2,rmat3,rmat4] = cooc(image,1,D);
%green
[gmat1,gmat2,gmat3,gmat4] = cooc(image,2,D);
%blue
[bmat1,bmat2,bmat3,bmat4] = cooc(image,3,D);

%compute mean value
%red
rmat_mean = (rmat1+rmat2+rmat3+rmat4)/4;
%green
gmat_mean = (gmat1+gmat2+gmat3+gmat4)/4;
%blue
bmat_mean = (bmat1+bmat2+bmat3+bmat4)/4;

%compute range value
%red
rmat_range = max(rmat1,max(rmat2,max(rmat3,rmat4)))-min(rmat1,min(rmat2,min(rmat3,rmat4)));
%green
gmat_range = max(gmat1,max(gmat2,max(gmat3,gmat4)))-min(gmat1,min(gmat2,min(gmat3,gmat4)));
%blue
bmat_range = max(bmat1,max(bmat2,max(bmat3,bmat4)))-min(bmat1,min(bmat2,min(bmat3,bmat4)));


%mean value of correlation
%red
m_rcorrelation = correlation(rmat_mean);
%green
m_gcorrelation = correlation(gmat_mean);
%blue
m_bcorrelation = correlation(bmat_mean);

fvec(1,:) = [m_rcorrelation,m_gcorrelation,m_bcorrelation];

%range value of correlation
%red
r_rcorrelation = correlation(rmat_range);
%green
r_gcorrelation = correlation(gmat_range);
%blue
r_bcorrelation = correlation(bmat_range);

fvec(2,:) = [r_rcorrelation,r_gcorrelation,r_bcorrelation];

