function fvec = create_sumRGB_correlation(image,D)
%-------------------------------------------------------------------------
% function fvec = create_sumRGB_correlation(image,D)
% 
% Calculation of the feature vector
%
% input:    image              (n x m x 3) matrix containing information about a rgb
%                               picture      
%           D                   distance in pixel for the calculation of the co-occurence matrix    
%
% output:   fvec                feature vector
%-------------------------------------------------------------------------
% Date: 2.11.2004
% Name: Maja Temerinac

%feature vector containing
%correlation(mean,range)

n = 2;
fvec = zeros(n,1);


%compute co-occurance matrix
%red
[rmat1,rmat2,rmat3,rmat4] = cooc(image,1,D);
%green
[gmat1,gmat2,gmat3,gmat4] = cooc(image,2,D);
%blue
[bmat1,bmat2,bmat3,bmat4] = cooc(image,3,D);

%compute sum(rgb)
mat1 = rmat1 + gmat1 + bmat1;
mat2 = rmat2 + gmat2 + bmat2;
mat3 = rmat3 + gmat3 + bmat3;
mat4 = rmat4 + gmat4 + bmat4;

%compute mean value
mat_mean = (mat1+mat2+mat3+mat4)/4;


%compute range value
mat_range = max(mat1,max(mat2,max(mat3,mat4)))-min(mat1,min(mat2,min(mat3,mat4)));

%mean value of correlation
m_correlation = correlation(mat_mean);

fvec(1) = m_correlation;

%range value of correlation
r_correlation = correlation(mat_range);

fvec(2) = r_correlation;

