function val = find_sim_images_contrast(image,colordb,D)
%-------------------------------------------------------------------------
% function val = find_sim_images_contrast(image,colordb)
% 
% Calculation of the most similar images from the db given a reference
% image
%
% input:    image                reference rgb image
%           colordb              color database  
%           D                    distance in the co-occurence matrix  
%
% output:   val                   (n x 6) vector for the distance between the feature vector of the colors red green
%                                 and blue of the image and the feature
%                                 vector of each image in the colordb
%                                 sorted in ascending order. In one row the
%                                 values of the absolut difference of the
%                                 features vectors and the number of the
%                                 image of the database that is compared to
%                                 the input image interchange for the
%                                 colors red, green and blue
%-------------------------------------------------------------------------
% Date: 2.11.2004
% Name: Maja Temerinac

[m n] = size(colordb);

% Here you can choose the number of features 
%---------------------------------------------------
ftsvec_image=create_RGB_contrast(image,D);
%----------------------------------------------------
abstand = zeros(n,3);
for i= 1:n
    spalteR = colordb(i).ftsvec(:,1);
    spalteG = colordb(i).ftsvec(:,2);
    spalteB = colordb(i).ftsvec(:,3); 
    abstandR = norm(ftsvec_image(:,1)-spalteR);
    abstandG = norm(ftsvec_image(:,2)-spalteG);
    abstandB = norm(ftsvec_image(:,3)-spalteB);
    abstand(i,:) = [abstandR,abstandG,abstandB];
end

[abstand(:,1),indexR] = sort(abstand(:,1));
[abstand(:,2),indexG] = sort(abstand(:,2));
[abstand(:,3),indexB] = sort(abstand(:,3));

val = [abstand(:,1),indexR-1,abstand(:,2),indexG-1,abstand(:,3),indexB-1];